package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`MP`!````,"5```````!``````````(BC````
M`````````$``.``(`$``&P`:``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````;`````````!L``````````0`````````!````
M!0````````````````!``````````$````````R9````````#)D`````````
M``$```````$````&````P)T```````#`G4$``````,"=00``````B`0`````
M``#P%````````````0```````@````8```#8G0```````-B=00``````V)U!
M`````````@`````````"````````"``````````$````!````!P"````````
M'`)````````<`D```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```#`G0```````,"=00``````P)U!``````!``@``````
M`$`"`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4``.`O+YYH@60<8TQ22H+P]]Q42OIA````!0```!`````*````H!``*`)&
M$0```&``5@)0&(((!"!(`!$1``@0`@`@`````````$@"(`X`"P``A`*H00@%
M(&@(Q$DX0A25!D$H"BA8B($%8`26"`E"2G!``!@!`4!""`!`@(S`!``($)`0
M`P$`"($8@(%`0(*9@"Q`"`(!!"``8``)!)$CA(J75&`%``````````8````'
M````"0`````````````````````````*````#`````X````0````$0```!(`
M```4````%P`````````9```````````````:````'0```!X`````````(@``
M`",````D`````````"4````F````*@`````````L```````````````M````
M+@```"\````P`````````#0````U`````````#D``````````````#H````]
M````/@`````````_````0````$(```!$````1P````````!*````2P```$P`
M``!-`````````$X```````````````````````````````````!/````4```
M``````!2`````````%0```!6````6`````````````````````````!9````
M70````````!?`````````&$`````````8P```&0``````````````&8```!G
M````:0```&H```!M````7Y:3'*-:[Y#"CH?_5]N3'`TZEPO2402$@72"#7KP
M2FM]08[%=E0\E,T_#*_W(\X@B0=PTR!TL`+59-1\9J_,9BY./?;;]P!>!J2'
M_P&O-.BQ2)WGSMY'+>"G`@K/2J[_XT?&`3Y^EGS&#N`][#^0`FUSA<7%B060
M89CO$@$C^:2=NY,<0D75['SM$0]0[A'CA_F<@5J:.P^[E9,<04V=?*?=HVM9
M[Y=Y.?*+'`P4XIX$,J6%H@+V&=O-XY[[H6Q@ZM/O#L@Y0!\R8MOMN8WQ#NG[
MP\+LWI,<2B)]_PN*$%>M2^/`V7%8'"O0X2(:G]:]+0ZQ<U@[0!_#Y3\LF"+4
M:+KCDGPA_^0.BIC=PFYZ:?J+V357DZT$8C?C\,%#\N_(WX4@3U>DFY;%N9Q`
M4!M]7S&X@@V^VE<;LP&+;W9OXW"]T$M]GB+'J&L)0]8A8F0'?JF<FV+0^H+L
M+/:+:W^:?-"?+/R'\)9\[@M1^?/;TQV0=8(-0V9+$`5LLLT\K3D-%^I:\:/@
M^TGB5\085Y):4OW2[P]NQ=\??)`0Z2W?_D@NQ9NVWJO*G\G5LG$`````````
M```````````````````````1````(``````````````````````````M````
M(``````````````````````````\````(`````````````````````````!0
M````(`````````````````````````"$`P``$@```#`A0```````````````
M``!'`@``$@```#`@0`````````````````#"`@``$@```)`?0```````````
M``````#>`@``$@```(`B0`````````````````!Y!```(``7`"BB00``````
M``````````#-`0``$@```.`A0`````````````````"[`@``$@```$`B0```
M``````````````"]`0``$@```#`?0``````````````````%!0``$@`-`!17
M0```````0`````````#B`P``$``8`$BB00````````````````!U`@``$@``
M`.`?0`````````````````"@`@``$@```+`B0`````````````````"Y!```
M$0`7`$"B00``````"``````````A`P``$@```.`>0``````````````````A
M!0``$@`-`*!20```````^`,```````!>!```$@`-`-Q#0```````-`$`````
M``"+`P``$@```/`?0`````````````````"&`@``$@```(`@0```````````
M```````R`P``$@`````?0`````````````````#Q`P``$``8`+"R00``````
M```````````/`0``$@```"`A0`````````````````!J!```$@`-`.1(0```
M````O`D```````"3!```$@`-`-1`0```````\``````````\!```$@```$`A
M0`````````````````!1!```$@`-`+Q#0```````(`````````!P`@``$@``
M`-`>0`````````````````"M`@``$@```'`@0`````````````````"6`0``
M$@```'`A0``````````````````.`P``$@```(`A0`````````````````">
M`P``(0`8`&BB00``````"``````````O`@``$@```%`B0```````````````
M```V`@``$@```*`B0`````````````````#0`@``$@```+`>0```````````
M``````#/`P``$``7`$BB00````````````````"U`@``$@```-`@0```````
M``````````#K`@``$@```!`A0`````````````````">````$@```"`B0```
M```````````````I`@``$@```*`@0`````````````````!6`P``$@`````B
M0`````````````````!/`@``$@```#`B0`````````````````"?`P``(0`8
M`&BB00``````"`````````#\`P``$``8`+"R00`````````````````K`P``
M$0`8`$BB00``````"``````````)!```$@`-`.!70```````!`````````"A
M`0``$@```,`?0`````````````````!O`0``$@```+`@0```````````````
M``"I!```$@`-`&A70```````>`````````#E!```$@`-`*!'0```````1`$`
M```````3!```$@`.`.170`````````````````"/`@``$@```)`@0```````
M``````````!]!```$@`-`#`E0`````````````````#2!```$@`+`$@>0```
M``````````````"^````$@```&`A0`````````````````#)`@``$@```*`>
M0````````````````````P``$@```+`?0``````````````````"`0``$0`8
M`%BB00```````0````````"$!```$0`/`/A70```````!`````````#6`P``
M$``8`$BB00````````````````!=`P``$@```,`A0`````````````````!U
M`P``$@```)`>0`````````````````!J````$@```+`A0```````````````
M```<`0``$@```/`A0`````````````````#0!```$@`-`%!`0```````-```
M```````X`0``$@```'`?0``````````````````$!```$``8`+"R00``````
M``````````#8!```$@`-`,A!0```````]`$```````#3````$@```"`?0```
M``````````````!>`@``$@```$`?0`````````````````"'````$@```)`B
M0``````````````````5`@``$@```&`@0`````````````````"O`0``$@``
M`!`B0`````````````````#A````$@```!`@0`````````````````#S````
M$@```&`B0``````````````````M`0``$0`8`%"B00``````!`````````"=
M`P``$0`8`&BB00``````"`````````!A`0``$@```-`?0```````````````
M``#7`@``$@`````@0`````````````````#P`P``$``8`+"R00``````````
M``````#W!```$@`-`.1&0```````E``````````9`P``$@```!`?0```````
M``````````"O````$@```&`?0`````````````````!G`P``$@```,`>0```
M``````````````!W!```$``7`"BB00````````````````"]`P``$0`8`&"B
M00``````"``````````J!```$@`-`'A'0```````*`````````#K`0``$@``
M`"`@0`````````````````#8`0``$@```%`@0`````````````````"8`P``
M$@`-`-`B0```````5`(```````!"`P``$@`````A0``````````````````]
M`0``$@```*`A0``````````````````Y`P``$@```/`>0```````````````
M``#V`0``$0`8`'"B00``````$P````````#Y`@``$@```(`>0```````````
M``````#E`@``$@```%`A0`````````````````!]`@``$@```%`?0```````
M``````````#D`0``$@```*`?0`````````````````!]`P``$@```.`@0```
M``````````````##!```$@`-`!!%0```````U`$```````!)`P``$@```(`?
M0`````````````````!"`0``$@```-`A0`````````````````"G`@``$@``
M`,`B0`````````````````!%!```$@`-`)A60```````?`````````!X````
M$@```/`@0`````````````````!_`0``$@```'`B0``````````````````9
M!```$@`-`,1!0```````!`````````"(`0``$@```$`@0```````````````
M``!.`0``$@```)`A0```````````````````;&EB<&5R;"YS;RXU+C(P`%])
M5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?2G9?
M4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7W-A=F5?9&5S=')U8W1O
M<E]X`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A
M:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!0
M97)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=35G!V`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P97)L7V1E
M<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R
M<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R
M87``;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`
M;W!E;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N
M-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO
M<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!A
M8F]R=`!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T
M<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?
M;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D
M;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S
M<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T
M7VUA:6X`7U]E;G9I<F]N`&QD+6QI;G5X+6%A<F-H-C0N<V\N,0!?7W-T86-K
M7V-H:U]G=6%R9`!?961A=&$`7U]B<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?
M7V)S<U]E;F1?7P!?7V5N9%]?`%]E;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C
M=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L
M96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?
M7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`<&%R7VEN:71?96YV`'AS
M7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?
M8VQE86X`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`%A37TEN=&5R;F%L
M<U]005)?0D]/5`!'3$E"0U\R+C$W```````````````"``,``@`"``$````"
M`````0`!``(``@`!``(``0`!``(``@`"``$````!``$``@`!``(``@````(`
M`@`#``,``@`!``(``@````,``@`#``(``0`"``$```````$``0`!``(``0`!
M`````@`"`````0`!``(``@```````0````$``0````(````#````````````
M`@````(``0`!``(````"``$`!``!```````!``(``@`"`````@`"``(``@`"
M``$``@````(``0```````0```````````````0`!`*<#```0````(````)>1
ME@8```0`-P4````````!``$`!0(``!`````@````EY&6!@```P`W!0``````
M``$``0!4`@``$`````````"7D98&```"`#<%````````X)]!```````!!```
M`@``````````````2*)!````````!```+P``````````````4*)!````````
M!```3@``````````````6*)!````````!```/```````````````8*)!````
M````!```6```````````````:*)!````````!```3P``````````````<*)!
M````````!```8````````````````*!!```````"!```80``````````````
M"*!!```````"!```0```````````````$*!!```````"!```.@``````````
M````&*!!```````"!```)0``````````````(*!!```````"!```5@``````
M````````**!!```````"!```'@``````````````,*!!```````"!```$@``
M````````````.*!!```````"!```7P``````````````0*!!```````"!```
M%P``````````````2*!!```````"!```5```````````````4*!!```````"
M!```1P``````````````6*!!```````"!```#```````````````8*!!````
M```"!```2```````````````:*!!```````"!```8P``````````````<*!!
M```````"!```50``````````````>*!!```````"!```1```````````````
M@*!!```````"!```9P``````````````B*!!```````"!```!P``````````
M````D*!!```````"!```9```````````````F*!!```````"!```.P``````
M````````H*!!```````"!```,0``````````````J*!!```````"!```4```
M````````````L*!!```````"!```#P``````````````N*!!```````"!```
M%0``````````````P*!!```````"!```40``````````````R*!!```````"
M!```3```````````````T*!!```````"!```6@``````````````V*!!````
M```"!```!@``````````````X*!!```````"!```;@``````````````Z*!!
M```````"!```6P``````````````\*!!```````"!```2@``````````````
M^*!!```````"!```'P```````````````*%!```````"!```%@``````````
M````"*%!```````"!```-@``````````````$*%!```````"!```*@``````
M````````&*%!```````"!```,@``````````````(*%!```````"!````@``
M````````````**%!```````"!```)P``````````````,*%!```````"!```
M90``````````````.*%!```````"!```:P``````````````0*%!```````"
M!```70``````````````2*%!```````"!```*```````````````4*%!````
M```"!```&0``````````````6*%!```````"!```!0``````````````8*%!
M```````"!```'```````````````:*%!```````"!```8@``````````````
M<*%!```````"!```.0``````````````>*%!```````"!```(```````````
M````@*%!```````"!```(0``````````````B*%!```````"!```;P``````
M````````D*%!```````"!```7@``````````````F*%!```````"!```00``
M````````````H*%!```````"!```/P``````````````J*%!```````"!```
M:```````````````L*%!```````"!```"@``````````````N*%!```````"
M!```0@``````````````P*%!```````"!```*P``````````````R*%!````
M```"!```2P``````````````T*%!```````"!```*0``````````````V*%!
M```````"!```+```````````````X*%!```````"!```"P``````````````
MZ*%!```````"!```(P``````````````\*%!```````"!```30``````````
M````^*%!```````"!```;````````````````*)!```````"!```"```````
M````````"*)!```````"!```20``````````````$*)!```````"!```)```
M````````````&*)!```````"!```$```````````````(*)!```````"!```
M:0``````````````_7N_J?T#`)'*`0"4_7O!J,`#7]8`````\'N_J=```)`1
M_D?Y$.(_D2`"']8?(`/5'R`#U1\@`]70``"P$0)`^1`"`)$@`A_6T```L!$&
M0/D0(@"1(`(?UM```+`1"D#Y$$(`D2`"'];0``"P$0Y`^1!B`)$@`A_6T```
ML!$20/D0@@"1(`(?UM```+`1%D#Y$*(`D2`"'];0``"P$1I`^1#"`)$@`A_6
MT```L!$>0/D0X@"1(`(?UM```+`1(D#Y$`(!D2`"'];0``"P$29`^1`B`9$@
M`A_6T```L!$J0/D00@&1(`(?UM```+`1+D#Y$&(!D2`"'];0``"P$3)`^1""
M`9$@`A_6T```L!$V0/D0H@&1(`(?UM```+`1.D#Y$,(!D2`"'];0``"P$3Y`
M^1#B`9$@`A_6T```L!%"0/D0`@*1(`(?UM```+`11D#Y$"("D2`"'];0``"P
M$4I`^1!"`I$@`A_6T```L!%.0/D08@*1(`(?UM```+`14D#Y$(("D2`"'];0
M``"P$59`^1"B`I$@`A_6T```L!%:0/D0P@*1(`(?UM```+`17D#Y$.("D2`"
M'];0``"0$6)`^1`"`Y$@`A_6T```D!%F0/D0(@.1(`(?UM```)`1:D#Y$$(#
MD2`"'];0``"0$6Y`^1!B`Y$@`A_6T```D!%R0/D0@@.1(`(?UM```)`1=D#Y
M$*(#D2`"'];0``"0$7I`^1#"`Y$@`A_6T```D!%^0/D0X@.1(`(?UM```)`1
M@D#Y$`($D2`"'];0``"0$89`^1`B!)$@`A_6T```D!&*0/D00@21(`(?UM``
M`)`1CD#Y$&($D2`"'];0``"0$9)`^1""!)$@`A_6T```D!&60/D0H@21(`(?
MUM```)`1FD#Y$,($D2`"'];0``"0$9Y`^1#B!)$@`A_6T```D!&B0/D0`@61
M(`(?UM```)`1ID#Y$"(%D2`"'];0``"0$:I`^1!"!9$@`A_6T```D!&N0/D0
M8@61(`(?UM```)`1LD#Y$((%D2`"'];0``"0$;9`^1"B!9$@`A_6T```D!&Z
M0/D0P@61(`(?UM```)`1OD#Y$.(%D2`"'];0``"0$<)`^1`"!I$@`A_6T```
MD!'&0/D0(@:1(`(?UM```)`1RD#Y$$(&D2`"'];0``"0$<Y`^1!B!I$@`A_6
MT```D!'20/D0@@:1(`(?UM```)`1UD#Y$*(&D2`"'];0``"0$=I`^1#"!I$@
M`A_6T```D!'>0/D0X@:1(`(?UM```)`1XD#Y$`('D2`"'];0``"0$>9`^1`B
M!Y$@`A_6T```D!'J0/D00@>1(`(?UM```)`1[D#Y$&('D2`"'];0``"0$?)`
M^1""!Y$@`A_6T```D!'V0/D0H@>1(`(?UM```)`1^D#Y$,('D2`"'];0``"0
M$?Y`^1#B!Y$@`A_6T```D!$"0?D0`@B1(`(?UM```)`1!D'Y$"((D2`"'];0
M``"0$0I!^1!"")$@`A_6T```D!$.0?D08@B1(`(?UM```)`1$D'Y$(((D2`"
M'];]>[JI_0,`D?-3`:GU6P*IU```D*!/`+F#@@F1H2,`^:(?`/FA`P&1HN,`
MD:`S`9%D`$#YI"\`^00`@-+3``"0>/__EP(``)````"00D`&D0"`")'A`P*J
M"PT`E,```)``8$DY0`$`-3K__Y?"``"P0%0!^:`.`+33``"0!?__EV!20KE#
M__^7'U0B.6!20KE`__^7X@,`JF!20KE!R%(Y(0`?,D'($CDZ__^7`LA2.:%/
M0+GB`V>>0@``,B$4`!$"R!(YH0P`7"%\0),@`&.>`"AB'A`@81ZL"0!4(/!]
MT],``+`G__^7Y0,`JL8``)"A(T#Y9"(.D:)/0+D#``#P````\"@`0/EC@#&1
MQR!!^0"@,9&&`(!2A0`1^*@``/E?!`!QHP0`^:<(`/F@#`#YAH`0N&T'`%0A
M(`"11A``$:``@%+G`("2X\P@BR2$0/@`!``1'P`&:Z1H(_AA__]4X`"`DG8B
M#I$&S":+`0``T`0`@-+C`P6JP`)2^$(,`!$A$`*1OV@F^&+__Y?U`P`JX`(`
M-'8B#I'``E+XU?[_EP```/"A4P&1`.`FD18%`)1@`@"T<R(.D92""9%@`E+X
MN/[_ET?__Y>B+T#Y@0)`^4$``<K@`Q4JP0,`M?-30:GU6T*I_7O&J,`#7];`
M`E+X;/__E_4#`"KG__\7P()1^$`!`+1Q#`"4Z___%\$``)````#P(<`)D0!@
M,9$=__^71@`&"\___Q<```#PH5,!D0``)9'T!`"4P((1^,#[_[1B#`"4W/__
M%R``@%)M_O^7W/[_EQ\@`]4```````#`0QT`@-(>`(#2Y0,`JN$#0/GB(P"1
MY@,`D<```%CC``!8!`$`6*?^_Y?>_O^7`````-`B0```````:%=```````#@
M5T```````*```/``\$?Y0```M,_^_Q?``U_6`````,$``)#```"0(2`)D0`@
M"9$A'`"1(0``RS\X`/&)``!4@0``6$$``+0@`!_6P`-?U@``````````P0``
MD,```)`A(`F1`"`)D2$``,LB_$.30OQ"BT'\09.!``"TH@``6$(``+1``!_6
MP`-?UA\@`]4``````````/U[OJG]`P"1\PL`^=,``)!@#DHY@```-=S__Y<@
M`(!28`X*.?,+0/G]>\*HP`-?UOU[OZF@``#P_0,`D0!`-Y$!`$#Y80``M?U[
MP:C=__\7@0``6*'__[0@`#_6^___%P``````````_T,*T<X``)#!@0F1"N``
MD0O@`9']>[JI_0,`D?-3`:GU6P*I]V,#J?EK!*G[<P6IIJ,!D2(`0/FB=P'Y
M`@"`TD&%0/C&0`"1)-QXTR+\8-,I'&C3)?Q(TX0<<))(W'C3I1QXDH0`":HC
M_&C3A``%JD(<:-,%'7"28QQXDJ(``JHG?%C30@`#JH0`!ZI!X$&J7P$+Z\0`
M'_C!@!_X(?W_5*&C`9&C0P.1)J`)D66`7?AC(`"188!?^&0`6OAB`%GXH0`!
MRB$`!,I_``;K(0`"RB+X?]-!?$&J(7Q`DF$(`/EA_O]4"P!`^2$SC]('$$#Y
M05"K\J(W0/EDZ7O3#`1`^81L2ZH-"$#YXP`"BP\,0/EC``&+H@$,BI"%8M/E
M`2R*8T`DBZ(``JJF.T#Y8P`"BQ`*3*ID?$"2$'Y`DJ4!*XKH`0:+@NA[TP8"
M"XIQA6+3Q@`%JD)L1*H(`0&+I3]`^3$*2ZHQ?D"2"`$&BPH")(JE`06+8P`1
MB@A!(HL"?4"2I0`!BT,!`ZJ&A&+3J@`#BT7H>].R0T#YQ`A$JJ5L0JJ&?$"2
M(P(BBDD"`8L(`0:*14$EBU.$8M.D?$"28@I"JF,`"*HI`1"+R``DBBD!`XM#
M?$"2@NA[TZ4``XI";$2JL$=`^0@!!:J%A&+3$`(!B[)+0/DI02*+I`A$JB)]
M0)*%?$"2$0(1BU("`8LP`@B+9``BBBD!!8I(Z'O3A``)JD8"!HL(;4*JQ@`$
MBZI30/E$A&+3"$(HB[%/0/F""$*J2@$!BT1\0)("?4"2$`$$BC$"`8M*`06+
MI0`BBB,"`XM(Z'O3I0`0JK)70/EP``6+!6U"JD.$8M-2`@&+Q4`EBV((0JI#
M?$"2HGQ`DE0"!(NE``.*A``BBDCH>].$``6JL5M`^4H!!(L$;4*J181BT[-?
M0/D$0B2+H@A"JBD"`8M%?$"2@GQ`DG<"`8N$``6*,P$#BV,`(HI(Z'O38P`$
MJD2$8M.&`@.+`VU"JH((0JKW`@6+24$CBT1\0)(C?4"2(@$$BJ4`(XIJZ'O3
MI0`"JDIM0ZJR8T#Y:0(%B[%G0/EEA&+3QD`JBZ,(0ZIE?$"26P(!B\-\0)(Q
M`@&+R@`%BCD"!8M[`P2+<>A[TX0`(XHQ;D.JA``*JK)K0/GW`@2+9(1BTRE!
M,8N#"$.J9'Q`DB-]0)(Q`02*4@(!BZ4`(XIUZ'O31@($BZ4`$:JU;D.J>P,%
MB[AO0/EEA&+3P@!GGJ,(0ZKF0C6+97Q`DA@#`8O#?$"2U0`%BH0`(XH&`P6+
M>NA[TX0`%:I:;T.JPP!GGB8#!(MDA&+3:4,ZBX,(0ZJP>T#Y9'Q`DB-]0)([
M`02*I0`CBGKH>].E`!NJ20!FGEIO0ZJ^<T#Y`@(!BRD!!8MEA&+3QD`ZB[QW
M0/FC"$.JW@,!BV5\0)+#?$"2G`,!B]X#!(M``&>>Q@`%BH0`(XJ9`P6+A``&
MJGKH>]-F`&:>J']`^2(#9YZP@T#YV0`$BT1O0ZIFA&+3"`$!B\,(0ZHI022+
M!@!FGF1\0)(C?4"2*0$$BL8`!(NE`".*I0`)JK:'0/G``&>>9NA[T\D#!8O&
M;$.J981BTR)TG=*C"$.J)D,FBV5\0)+#?$"2"`$%B\8`!8J$`".*(MNM\@$!
M9YZ$``:J:.A[T]8"`HM&`&:>"&U#J@$"`8NJCT#YV0`$BV2$8M,H02B+@PA#
MJF1\0)(#?4"2"0$$BJ4`(XH&`&:>:.A[TZ4`":HA``2+R0`%BP5M0ZIFA&+3
ML(M`^25#)8O#"$.JN7Q`DF-\0)*F``.*A``YBL4"`XN$``:J)@!FGC:'8M.B
M`&>>)>M[T\8`!(ND;%FJU@I9JK&30/DD022+V7Y`DH5\0)*$`!F*8P`EBJGH
M>]-C``2JI(1BT[*70/DA``.+M)M`^2-M1:JSGT#YA0A%JK6C0/G&0".+J<-`
M^<-\0)*DQT#Y2@$"BRD!`HL0`@*+A``"BQ`"&8LA`6>>J0`6RH``9YXF`09*
M1`!FGG:$8M-9026+,0("BXD`!HMFZ'O3QFQ#JL,*0ZIE``7*I,M`^2%`)HLQ
M0B.+-GQ`DJ4``4H0`@6+Q>I[TZ5L5JK&AF+3Q@A6JHH``HLA026+U@`#RB-\
M0)+!`@%*=NA[TV6$8M/6;D.J*0,!BZ,(0ZJATT#YN*=`^64`!LJWJT#Y$$(V
MB[NS0/D6?D"2O+M`^;4"`HNZKT#Y]P("B[ZW0/E[`P*+J+]`^5H#`HNDST#Y
MW@,"BP@!`HNP`!!*A``"BU("`HN4`@*+<P("BQ@#`HN<`P*+I=M`^2(``HN!
MFY?2,0(0BV'CL?+0ZGO3I0`!BQ!N5JJ40B.+4D(FBZ(`9Y[%AF+3M@A6JJ;7
M0/G%`@/*(T$PBW!\0)*C``-*20(#BP/J>]/&``&+8VQ0J@6&8M-S0C:+PP!G
MGB9"(XO1?$"2I0A0JK8`%LHPZGO3$&Y1JL8"!DHVAF+3HT(EB]8*4:J&`@:+
MT0(%RB5!,(NP?$"2)0(%2G("!8L%ZGO3I6Q0JA&&8M,Q"E"J&$,VB\9`)8LV
M`A;*T'Q`DL8"!DIC``:+!NI[T\9L4*H5AF+3M0I0JN5",8M)0B:+L`(1RC%]
M0)()`@E*,.I[TS:&8M,0;E&JU@I1JD9#-8O1`A7*8T`PBPD#"8MU?$"2(P(#
M2K#J>].E``.+$&Y5JJ.&8M-C"%6J=T,VBRE!,(MV`!;*-7U`DLD""4K8``F+
MJ>I[TREM5:JVAF+3U@I5JMM#(XO5`@/*HT`IBVE\0)*C`@-*]P(#BR/I>]-C
M;$FJ-85BT[4*2:J<0S:+!D,CB[8"%LK)?$"2&D$UBRCI>]/&`@9*"&U)JC:%
M8M/6"DFJ9@,&B^5"*(O5`A7*J7Q`DJ4"!4HHZ7O3-85BTPAM2:JU"DFJJ0(6
MRH4#!8O&0"B+N=]`^0@`9IZTXT#Y(P!FGCD#`8L(036+L^=`^6-`-HNRZT#Y
M``%GGLA\0)(F`09*"85BTUH#!HL&Z7O3QFQ(JBD)2*HU`17*L>]`^:5`)HM;
M02F+IGQ`DJ4"!4IJ``6+R(1BT\7H>],("4:JI6Q&J@D!"<J<0"B+L/-`^4-#
M)8N^]T#Y!`!FGF9\0)(C`0-*Q>A[TX,``XND"T'YI6Q&JLF$8M.$``&+)@E&
MJL@`",JX^T#Y@0!GGD1!)8N%?$"26D`FBZ+H>].JA&+30FQ%JDH)1:H$`01*
M1@$&RF-`(HMD`P2+8@!FGJ@/0?FW_T#YE`(!BUM`*HMB?$"21>A[T\,``TJ)
M`P.+"`$!BZ5L0JI#A&+38PA"JK8#0?E"`&:>A$`EBP`!9YYH``K*2D`CBX)\
M0)($`01*181BTT@#!(M$Z'O3A&Q"JJ4(0JJF``.JHP`#BB1!)(LI0R6+@GQ`
MDH0`!HJ#``,J6NA[TV8#`XNC%T'Y1(1BT[4'0?E[``&+0V]"JH0(0JJ\$T'Y
M"$$CBX(`!:H#?4"2A0`%B@(!`HIHZ'O30@`%*F6$8M.E"$.J"&U#JJ,?0?ES
M`@&+NAM!^<9`*(MY``&+HR-!^:@`!*H0`@&+&`,!B]8"`8NU`@&+E$(DB\@`
M"(I2`@&+,0(!B]X#`8OW`@&+G`,!BUH#`8ND``2*80`!B\-\0)($`00J9NA[
MT\9L0ZHI`02+9(1BTTH!`HN$"$.J2D$FBX8`!:I#?4"2:$(EBTH!!HJ%``6*
M9NA[TT4!!2K&;$.J`@%GGH@"!8MEA&+3*4$FBZ4(0ZI20B2+I@`$JJ0`!(HF
M`0:*(WU`DL0`!"ISZ'O31@!FGG-N0ZHQ0B6+PCJ8TL8`!(MDA&+3A`A#J@A!
M,XN*``6J`WU`D@H!"HH(0B2+A0`%BD),N?("`6>>10$%*FCH>]-*`@6+"&U#
MJF6$8M.E"$.JLRM!^<9`*(NI``2JPWQ`DLD`"8JD``2*9NA[TR0!!"K&;$.J
M*0($BV2$8M.$"$.JJ#-!^4I!)HN&``6J$0$"B]Y#)8M(`0:*A0`%BD-]0)(%
M`04J2`!FGF;H>]/&;$.J"D,DBP@!!8MEA&+3I0A#JBE!)HNF``2J(WU`DB8!
M!HJD``2*:>A[T\0`!"K&`P2+*6U#JF2$8M/W0B6+A`A#J@A!*8N)``6J`WU`
MDH4`!8H(`0F*!0$%*GCH>]/)0B2+&&]#JDH!!8MEA&+3I0A#JL9`.(LC`6>>
MJ0`$JL-\0)+)``F*ID(EBZ0`!(HD`00JJ#]!^<(`9YYFZ'O3Z0($B\9L0ZID
MA&+3%0$"BX0(0ZI*02:+B``%JJ-#0?E(`0B*A0`%BB8`9IYV``*+!0$%*D-]
M0))H`&:>RD`DBV;H>].T)T'YQFQ#J@@!!8MEA&+3<P("BZ4(0ZHI02:+I@`$
MJB-]0)(F`0:*I``$B@D`9I[$``0J1@!FGI0"`HLI026+LB]!^<8`!(MDA&+3
M(`%GGFGH>],I;4.JA`A#JE("`HNP-T'Y"$$IBXD`!:H#?4"2"0$)BH4`!8IH
MZ'O3)0$%*@AM0ZI*`06+981BTZ4(0ZK&0"B+J0`$JL-\0)*<0R2+R0`)B@@`
M9IZD``2*9NA[TR0!!"H)`02+QFQ#JJA/0?EDA&+32D$FBX0(0ZH(`0*+0WU`
MDF;H>]-[0R6+``%GGH@`!:K&;$.JA0`%BD@!"(I:0R2+"`$%*F6$8M.E"$.J
M*4$FBR-]0)*F``2J)@$&BFGH>].D``2**6U#JH@#"(O&``0J9(1BTPA!*8N$
M"$.J`WU`DHD`!:HY0R6+"0$)BFCH>],(;4.JA0`%BF8#!HLE`04J:81BT\9`
M*(LC"4.JR'Q`DFD`!*HA0"2+Q@`)BF0`!(H)Z7O3Q``$*BEM2*H&A6+3Q@A(
MJD4#!8LD`P2+I4`IB]D``ZJI?$"2N0`9BF5")HN40B.+PP`#BB,#`RHHA6+3
MI`!GGB7I>],A``.+HVQ)J@@)2:H0`@*+@T`CBP8!!LII?$"2Q@`#2H,"!HLE
MZ7O3I6Q)JJ1O0?EB`&>>(X5BTV,(2:J4``*+)$`EBVD`",I20BB+B'Q`DH$`
M9IXD`01*!NE[TPF%8M/&;$BJ)``$BT$`9IXI"4BJ*`$#RB5"(XLC0":+$$(I
MBV9\0)(#`0-*00(#B\/H>]-C;$:JR(1BTP@)1JJ^.T'Y"0$)RH1`(XN&?$"2
M)`$$2J4`!(O$Z'O3A&Q&JM*$8M-2"D:JW@,"BR%`)(M&`@C*PT,HBRA\0)+!
M``%*!NE[T\9L2*H)A6+3*`E(JJI30?FD0C*+I4`FBQ(!$LJF?$"22@$"BT4"
M!4II``6+Q>A[TZ5L1JJZ8T'Y00%GGL.$8M.J6T'Y9@A&J@$"`8M3`P*+6P$"
MB[%S0?G60BB+(4`EB\@`",JX1T'YMTM!^25\0)*\5T'Y`0$!2JI?0?D8`P*+
MNF=!^?<"`HNY:T'YG`,"BTH!`HM:`P*+.0,"BR("`HN1``&+H>A[TR%L1:JH
MA&+3"`E%JAA#)HLC02&+!0$&RF9\0)*C``-*Q>A[T\F$8M.E;$:J*0E&JB8!
M",KA0BB+)$(EB\,"`XN(?$"2Q``$2@;I>],0A6+3QFQ(J@@*2*H%`&:>!`,$
MBV-`)HO.@0F1)@!FGJ5`*8L)`0G*TD`HBV9\0)(C`0-*R81BTS```XO#Z'O3
M8VQ&JBD)1JHH`0C*A$`CBX-#*8N&?$"2!`$$2J4`!(O$Z'O3A&Q&JM&$8M,Q
M"D:J`4(DBR8""<HI?$"2P0`!2B;I>],HA6+3QFQ)J@D)2:ID0S&+,0$1RJ5`
M)HM!`@&+IGQ`DB4"!4IH``6+Q>A[TZ5L1JK#A&+39@A&JDI!*8LA0"6+R0`)
MRB5\0)(A`0%*D``!BZ'H>],A;$6JJ81BTRD)1:IS0B:+`T$ABR4!!LIF?$"2
MHP`#2L7H>]-#`0.+I6Q&JLJ$8M-*"4:J04,IBP1")8M&`0G*B7Q`DL0`!$HF
MZ7O3*(5BT\9L2:H)"4FJ)4,JBRH!"LIC0":+9`($BV9\0))#`0-**``#B\/H
M>]-C;$:JP81BTR8(1JJ40BF+A$`CB\D`"<J#?$"22D`FBR0!!$IBZ'O3I0`$
MBT)L0ZIDA&+3A`A#J@%!(HN'``<+!Q``^2=\0)*&``;*X^A[T^*$8M-C;$>J
M1PA'JN0`!,K!``%*HD`CBX$"`8M#?$"2@@`"2F3H>]-EA&+3A&Q#JJ,(0ZJ!
M``$+;0`-"R/H>],L``P+0@$"BV%L0:HA``(+YP`/"R$`"PL!``#Y!PP`^0T(
M`/D,!`#YH7=!^<`!0/D@``#*(`$`M?-30:GU6T*I]V-#J?EK1*G[<T6I_7O&
MJ/]#"I'``U_6\/G_E_U[O*G]`P"1]5L"J?=C`ZGS4P&I]@,`JO@#`:J``P"T
MH```\!<T0?DW`P"TP`)`.1_T`'&``P!48`,`-/0#%JJ`'D`X'_0`<4```%2@
M__\UE`(62_,"0/FS`0"TE'Y`D_4#%ZK@`Q.JX@,4JN$#%JJG^?^7@```-6!J
M=#@?]`!Q8`$`5+..0/CS_O^U``"`TO-30:GU6T*I]V-#J?U[Q*C``U_6%`"`
M4NO__Q>U`A?+@`8`D:'^0Y,!`P"Y8`(`B_-30:GU6T*I]V-#J?U[Q*C``U_6
M_7N\J?T#`)'S4P&I]1,`^;4``/#S`P"JH(()D0$`0/FA'P#Y`0"`TK0``/"A
MTP"1X`,3JK[__Y?@`0"THS=`N8(V0?E`S".+`01`^4'8(_CA_O^T`"``D0$$
M0/D!``#YH?__M:'3`)'@`Q.JL/__EV#^_[6U@@F1H1]`^:`"0/D@``#*H```
MM?-30:GU$T#Y_7O$J,`#7]:4^?^7_7NYJ?T#`)'S4P&I\P,!JOLK`/GU6P*I
M]V,#J?EK!*GT`P"JM@``\&`"0#G!@@F1(@!`^:(W`/D"`(#2'_0`<7,6DYK@
M`Q.J"?G_E_<#`*JADP&1X`,4JH[__Y?U`P"JH`<`M`+Y_Y<?0#?K@@8`5+5G
M0+FX``#P@`)`.1_T`'$@"P!4``L`-.`#%*H"```4@0``-`$<0#@_]`!QH?__
M5```%$L9-T'Y]PH`$>`"``LK^?^7(%LU^``*`+2C9T"Y@`8`D0(W0?F!`D`Y
M0EAC^$$``#FA```U!@``%`$40#A!'``X80``-#_T`'&!__]4H`>`4D$$`)%`
M```Y8!9`."`4`#C`__\U``"`4M:""9&B-T#YP0)`^4$``<HA!P"U\U-!J?5;
M0JGW8T.I^6M$J?LK0/G]>\>HP`-?U@``@-)A:F`XH6H@.``$`)&A__\U[O__
M%[@``/`;-T'Y8`-`^6`$`+3@`QNJ%0"`4@&,0/BU!@`1P?__M:`*`!$`?'V3
MH0``\"*(0KF"`0`TX0,`JN`#&ZHF^?^7`#<!^>`"`+2Z?D"3^0,`JEH'`)$_
M>SKXM6<`N;'__Q<B`(!2(H@"N>?X_Y?Y`P"J@`$`M+I^0)/A`QNJ0O-]TYWX
M_Y<9-P'Y\O__%P``@%*O__\7``*`TA4`@%+C__\7``"`$L3__Q<3^?^7_7NS
MJ?T#`)'S4P&I]5L"J?=C`ZFT``#P]0,`JH&""9$B`$#YHF<`^0(`@-)@``"T
M`0!`.6$!`#64@@F1H6=`^8`"0/D@``#*@`@`M?-30:GU6T*I]V-#J?U[S:C`
M`U_6FOC_E_8#`*J`_O^T&```T!A#(Y'@`Q:J0/G_E^4#`*K@!`"TH$Q`.1^X
M`'$@!0!4X`,5JK-,`)%T^/^7]P,`JN`#$ZIQ^/^7```7"P`(`!$`?$"3J?C_
ME_<#`*KE`Q.JY`,5JN,#&*H"`("2(0"`4FKX_Y>B(P&1X0,7J@``@%)N^/^7
M'P0`,:```%2@6T"Y``P4$A\00'&@`@!4X`,7JEKY_Y?@`Q>J%/G_E^`#%JH:
M^?^7Y0,`JF#[_[7@`Q:JQOC_E^`#%:KX^/^7P___%Z!00#D`^O\T'[@`<:'Z
M_U2@5$`Y@/G_--+__Q?@`Q>JK/__E^S__Q>\^/^7_7N]J?T#`)'S4P&ILP``
M\/43`/E@4D*YJ?C_EP%P0/E@4D*Y-01`^:7X_Y<!M$(Y8%)"N308`!*A^/^7
M``1`^0!`0'D`(!E3@`(`*J`&`'E@4D*YFOC_EP%P0/E@4D*Y-`1`^9;X_Y<!
M``#0`@"`TB%`,9'"^/^7@!8`^6!20KF/^/^7`7!`^6!20KDT!$#YB_C_EP%$
M0_E@4D*Y@1H`^8?X_Y<!<$#Y8%)"N30$0/F#^/^7`,!`^8`#`+1@4D*Y?_C_
MEP#`0/D!5$#Y8%)"N8$>`/EZ^/^7`7!`^6!20KDA!$#Y/R``^77X_Y<!<$#Y
M8%)"N2$$0/D_$`#Y</C_EP%P0/E@4D*Y,P1`^6SX_Y<`C$'Y8"8`^?-30:GU
M$T#Y_7O#J,`#7]8!`(#2Z/__%_U[OJG]`P"1\U,!J;,``/#T`P"J8%)"N5WX
M_Y<"8`:1X0,4J@``@%*A^/^7H```-```@%+S4T&I_7O"J,`#7]9@4D*Y4OC_
MEP"H0;D`#!02'Q!`<>```%1@4D*Y3/C_EP"H0;D`#!02'RA`<2'^_U1!`(!2
MX`,4JF7X_Y<?`!]KX!>?&O-30:G]>\*HP`-?UO\'0-$#``#0_X,`T>+_@=+]
M>[VI_0,`D?5;`JGS4P&ILP``\/4#`*I@8".18X()D?8#`:ID`$#YI"<(^00`
M@-*A(P&1TO?_EQ\`'VL-!`!4`00`4:(C`9$T?$"30FAT.$(#`#04?$"3H",!
MD>(#%*KA!8!2H!\`^9GX_Y>``@"TH```\`!00KD=^/^7HA]`^>,#%*KA`Q6J
MF?C_EW.""9&A)TCY8`)`^2```,K@`0"U\U-!J?5;0JG]>\.H_P=`D?^#`)'`
M`U_6`?W_-:```-``4$*Y"OC_E^(#%JKA`Q6JX_?_E^[__Q<1^/^7H```T/U[
MOZG]`P"1`%!"N0#X_Y<#``"PXO__L`$``+!C`""1_7O!J$+`/)$AH".1//C_
M%_U[OJG]`P"1\PL`^;,``-!@4D*Y\O?_E^W__Y=@4D*Y[_?_E_,+0/D$``"P
M`@``L(1`,9$!``"P_7O"J`4`@%+C`P2J0H`*D2$@))%(^/\7_PM`T?_#`-']
M>[VI_0,`D?43`/FU``#0\U,!J:"""9$!`$#YH2\0^0$`@-*D]_^7Y`,`*J$C
M`9&A'P#Y!0``L`,``+"@'T#YI8`DD6.@))$B`(+2(0"`4F7W_Y=`!/@WH4,`
MD0`*@M(```&+`@""T@!``-&@&P#YH!]`^:$;0/EG]_^7\P,`JO,"^#=@!@`1
M`'Q`DX[W_Y?T`P"J0`(`M'-^0).A&T#YX@,3JD#W_Y>?:C,XX`,4JK6""9&B
M+U#YH0)`^4$``<HA`0"U\U-!J?430/G]>\.H_PM`D?_#`)'``U_6``"`TO3_
M_Q>T]_^7Q/__%_\'0-$"``"P_T,`T?U[NJG]`P"1\U,!J?5;`JGW8P.I^6L$
MJ?LK`/FW``#0]`,`JD``)9'B@@F1\P,!JD,`0/FC-PCY`P"`TJ&3`9&P_?^7
M]@,`JN$%@%+@`Q2J]_?_EX`"`+0```"PX0,4J@!`)9$#_O^7X`,4JO>""9&B
M-TCYX0)`^4$``<I!"P"U\U-!J?5;0JGW8T.I^6M$J?LK0/G]>\:H_P=`D?]#
M`)'``U_6X`,4JAD``+`,]_^7^P,`*B&#)9'@`Q.J!/?_E_,#`*J@_/^T&```
ML!H``+`8XR216J,ED;6C`9%@`D`Y'P`?:W,2F)JV``"TX0,3JN`#%JJ:]_^7
M0`4`-.`#$ZKW]O^7X0,`*F#"((L`\%\X'[P`<0$!`%0A!`!1(GQ`DV,"`HM_
M:B(X8O!?.%^\`'%`__]48`<`$0$``0L__#]QS/C_5`,``+`"`(+2(0"`4N0#
M$ZKF`Q2JY0,:JF/`)9'@`Q6JLP``T.'V_Y=@4D*Y1_?_EP)@!I'A`Q6J``"`
M4N/V_Y?@```U8%)"N4#W_Y<`J$&Y``P4$A\@0''@``!4(8,ED0``@-+)]O^7
M\P,`JF#Y_[6I__\7(0"`4N`#%:I3]_^7X/[_-0```+#A`Q6J`$`ED:?]_Y?@
M`Q6JZ/;_EZ/__Q<V]_^7`0!`.<$``#0"!`"1/[P`<0`0@II!%$`XH?__-<`#
M7];]>[ZI_0,`D?-3`:GS`P"J8`,`M!0`0#DT`P`TKO;_EP`$`-%B`@"+?P("
MZV(!`%1@:F`X'[P`<:```%0>```40`!`.1^\`'%A`P!40@0`T5\`$^MA__]4
M?P("Z^$#`%2?O@!QP```5/-30:D```"P_7O"J`"@)9&_]O\70`"`TM'V_Y?A
M`P"JX`0`M`(``+!"X"210@!`>2(``'GS4T&I_7O"J,`#7]9``$`Y'[P`<4`!
M`%1"!`#1?P("ZV/__U1_`@+KH0``5.;__Q=``$`Y'[P`<8$``%1"!`#1?P("
MZV/__U1"`!/+0`@`D1\$0/&H`0!4H```T.$#$ZH`(`J1`P""TA0@`)%"!`"1
MX`,4JK'V_Y?@`Q2J\U-!J?U[PJC``U_6``"`TO-30:G]>\*HP`-?UOU[N*D!
M``"P````L"$`()']`P"1`.`ED?-3`:GU6P*I]QL`^;,``-`F'$&I)!1"J6*"
M"9$A8$!Y0P!`^:,_`/D#`(#2H>,`>:8?!:FD%P:I$OW_EQ4``+````"P%@``
ML``@)I$7``"P%```L`O]_Y>48B>1````L`!`)I$'_?^7````L`"`)I$$_?^7
MH*(FD0+]_Y<```"P`.`FD?_\_Y?``B61_?S_E^`B)Y'[_/^7X`,4JOG\_Y<`
M``"P`*`GD?;\_Y<```"P`$`ED?/\_Y<```"P`.`GD?#\_Y<```"P`"`HD>W\
M_Y<```"PH3,!D0!@*)&T_/^7@```M.$#`*K@`Q2J#/W_EP```+"A,P&1`,`H
MD:S\_Y>@``"T`@``L.$#`*I`("F1`_W_EP```+"A,P&1`&`ID:/\_Y=``@"T
MX0,`JL`")9'[_/^7`0``L*"B)I$A0"J1<X()D?;\_Y>A/T#Y8`)`^2```,H@
M`P"U\U-!J?5;0JGW&T#Y_7O(J,`#7]8```"PH3,!D0"@*9&-_/^7H```M.$#
M`*K@(B>1Y?S_E^K__Q<!``"P0@&`TB$`*I&@AP&11O;_EX#\_S6AKP&1X"(G
MD=O\_Y?@__\7;/;_E_U[O:G]`P"1\U,!J;0``-"S``#08(()D0$`0/FA%P#Y
M`0"`TH`Z0KD?!``Q(`$`5'.""9&B%T#Y80)`^4$``<J!`@"U\U-!J?U[PZC`
M`U_6````L*&3`)$`(">19?S_ER`!`+0!`$`Y/P`?:^('GQH_P`!QX`>?&D``
M``J`.@*Y[/__%P``@%*`.@*YZ?__%T?V_Y?]>[^I_0,`D>#U_Y=O]O^7@```
MM```0/G]>\&HP`-?U@``@-+]__\7_7NVJ0$``+#]`P"1(0`@D2'@`)'S4P&I
M]5L"J?=C`ZGY:P2IMP``T/8#`*KB@@F1,P!`^4,`0/FC3P#Y`P"`TB8$0/DD
M%$&I(@Q"J2`80/FS,P#YIC<`^:!+`/FD%P>IH@\(J1,#`+0%``"P`P``L+6C
M`9&Y@"61>,`ED08``!3A`Q:JE_;_ET`#`+2SAD#XLP$`M*%S`9'@`Q.J)OS_
ME_0#`*I@``"T`0!`.:'^_S7@`Q.JX0,6JGO\_Y>SAD#XL_[_M?>""9&A3T#Y
MX`)`^2```,I@`P"U\U-!J?5;0JGW8T.I^6M$J?U[RJC``U_6X`,6JH?U_Y?Z
M`P"JX`,4JH3U_Y=``P"+``@`D;WU_Y?Z`P"JY@,4JN4#&:KD`Q:JXP,8J@(`
M@)(A`(!2??7_E^$#&JK@`Q.J6_S_E]3__Q?L]?^7_R-`T0P``+#_`P71C`$@
MD8$A`I&.X0*1$#60TOU[N:G]`P"1Z"<&;?-3`:GU6P*I]V,#J?EK!*G[<P6I
MM```T*UC`I&*+4>I*"1`J28<0:DD%$*IP@U`J8]!0/F.@@F1C&5`^14``+#_
M0P#1]@,`JJ'S`9&@`B61T0%`^1%J/?@1`(#2KTL`^:HO"*FH)PNIIA\,J:07
M#:FB#0"IK`D`^=3[_Y?S`P"J8```M`$`0#GA'P`U>/__E_<#`*H`(`"TX`,7
MJD+U_Y<`^'_3``0`D7OU_Y<8``"PY`)`.?D#`*KS`P"J&(,JD20!`#3@`Q.J
MXP,8J@(`@)(A`(!2<PH`D3?U_Y?D'D`X)/__-:!;0/FAPP:1M\,"D3C0!-&`
M``"U#P``%.".0/B@`0"TX0,8JK#[_Y?S`P"J8/__M`$`0#DA__\T*_W_E^#^
M_S3@`Q.J1_7_E_,#`*K@`@"ULT-`^5,*`+1@`D`Y-P"`4F`!`#5.```4`#:0
MT@``'8L`S#>+`"1`T1-H1_D3"0"T8`)`.?<&`!&@"``TX`,3JA7]_Y>@_O\T
MX`,3JC'U_Y?S`P"J(/[_M.`#$ZH;``"P!/7_E_<#`*K@`QFJ`?7_EP``%PL7
M$!`1]WY`D^`#%ZHX]?^7^@,`J@8``+`#``"PYP,9JL:@*I%EHR61Y`,3JF/`
M*I$"`("2(0"`4O7T_Y<!.(!2X`,:JO+U_Y<?!``QH`0`5+,``-!@4D*Y5?7_
MEP)@!I'A`QJJ``"`4IGU_Y=@!0`TH```T`(``+##`D#YY`,:JD(@+9$A`(!2
M`"1!^73U_Y<``(#2E(()D0$UD-(B:'WX@0)`^4$``<H!.@"UOP,`D>@G1FWS
M4T&I]5M"J?=C0ZGY:T2I^W-%J?U[QZC_(T"1_P,%D<`#7]83`(#2PO__%\/U
M_Y<%`$"YOT0`<2#[_U2@``#0`@``L,,"0/GD`QJJ0@`KD2$`@%(`)$'Y5/7_
MEP``@-+@__\78%)"N23U_Y<`J$&Y``P4$A\00'$A^O]48%)"N1[U_Y<8L$&Y
MQ/3_EQ\#`&MA^?]48%)"N1CU_Y<`J$&Y`"``$A\`!W&A^/]4X`,7JN+T_Y?W
M`P"J````L*'S`9$`0#.1*OO_ER`S`+33`D#YQO3_E^$#`*K@`Q.J8?W_E_,#
M`*I`,@"TX`,3JI?T_Y<?#`!Q^`,`JNT!`%0`?$"3`0``L``0`-$A`"R18`(`
MBR[U_Y<``0`U'Q,`<8`H`%0`$P!18,(@BP#P7S@?O`!QX"<`5)+^_Y?````U
M`0"`4N`#$ZII]?^7_`,`*B`*`#4!``"P````L"%`*I$`(">1>Z,ED18``+!=
M^_^7$P"`4J[T_Y?F`P`J!P``L`,``+#G0#&1Y0,;JN0#&JIC@"R1`@"`DB$`
M@%+@`Q>J^`,'JOD#&ZK6PBR1;/3_EQ$``!1B]?^7``!`N1]$`'%!`@!4FO3_
MEW,&`!'F`P`J^`,`^><#$RKE`QFJY`,:JN,#%JH"`("2(0"`4N`#%ZI;]/^7
M`3B`4N`#%ZI8]?^7'P0`,8#]_U3@`QJJ#/7_E^$#%ZJ@`B61,OO_E^`#%ZJ'
M_O^7X`,7JF___Q>$_O^7X`,3JF[T_Y=K__\7H,,&D1,`@-*X8P*1&=`$T6!J
M>/B@`0"TX0,9JL;Z_Y=@``"T`0!`.6$``#5S(@"1^/__%U_T_Y?W`P"J0-[_
MM7,B`)'S__\7%P``L*`!@-+W8BJ1\/[_%T(`@%(A`H"2C/3_E\(`@-*AHP:1
MX`,<*@CU_Y>@HT8Y@```-:"G1CD?#`%Q@!\`5+F#`Y$"`(!2(^,`D0$`@-+@
M`QPJ:0!GGGST_Y>_AP#Y)&"$TB-QE=+"GYO2P8Z*T@`^G-*DZ*SRH_F]\D(7
ML_)!!J+R0'JX\J1S`/FC=P#YHGL`^:%_`/F@@P#YOXL`^;];`;D"`)#2H:,&
MD>`#'"KF]/^7'P`?:_@#`*KV`P`J+0D`5**'0/D`?T"3HXM`^4$,`(LA?$"2
M7P`!ZTD``%1C!`"1HEM!N6!T0(NAAP#YH(L`^8(5`#0!"(!2(,,BBS8``DL`
MX`"1'P,6:Z&C!I$6TY8:TWY`D^(#$ZK?\_^7H%M!N<`"``N@6P&Y'P`!<:'[
M_U2AHP:1X`,9JA8#%DLS`!.+T?7_E]_^`''-%`!4U@(!4<`")QX(!#HO``$F
M'O@#`"H8!P"1>!H8BZ%C!)'@`QFJ:"9`J68>0:ED%D*I8@Y#J2@D`*DF'`&I
M)!0"J2(,`ZES`@&1O/7_EW\"&.MA_O]4``$F'M8:`$O"?D"3X0,8J@,)@-(@
M`6:>]_/_E[9;`;D"`)#2H:,&D>`#'"J>]/^7'P`?:_@#`*KV`P`J+/?_5.`#
M'"HT]/^7LX=`^:)#.='C#X`282)#T[:+0/D@!``10L`ABQ_@`'%#H#TY[`X`
M5.(&@%*CPP:10@`!2V#`((L!`(!2`&`"T4)\0)/Z\_^7QOY8T\7^4-/$_DC3
M8_Y8TV+^4--A_DC3H(,#D;9/!3FF0P4YMN,%D:5'!3D8``"0I$L%.;F'!9&C
M4P4YW*(`D:)7!3FA6P4YLU\%.8+U_Y>E<T#YHW=`^:)[0/FS_%#3H7]`^;+\
M2-.@@T#Y<?Q8TW#\4--O_$C33OQ8TTW\4--,_$C3*_Q8TRK\4-,I_$C3"/Q8
MTP?\4-,&_$C3I'Q8T[.'!3D3@RJ1I(,%.;*+!3FECP4YL9,%.;"7!3FOFP4Y
MHY\%.:ZC!3FMIP4YK*L%.:*O!3FKLP4YJK<%.:F[!3FAOP4YJ,,%.:?'!3FF
MRP4YH,\%.0(``!0D%T`XX`,6JN,#$ZH"`("2(0"`4M8*`)%E\_^7WP(<ZP'_
M_U0'``"0`P``D.=`,9&FXP619:,ED>0#&JIC0"R1`@"`DB$`@%+@`Q>JOX,&
M.5?S_Y?@`QJJ#?3_E^$#%ZJ@`B61,_K_E^`#%ZJ(_?^7X`,7JG#^_Q>SHP:1
M:/__%]8&0/DVV/^TX`,6JD3S_Y<?#`#QJ=?_5``0`-$!``"0(2`LD<`"`(O=
M\_^7'P`?:W,2EIJU_O\7^`,3JG'__Q?B!X!20@`!2Z&#`Y$@P""+`0"`4D)\
M0),`X`"1A//_EZ"#`Y$>]?^7OZ<`^:!C!)$??`"I'WP!J1]\`JF#__\7H*M&
M.1\$`7%AX/]4H*]&.1\,`7$!X/]4H+-&.1\@`7&AW_]4H+=&.1\4`7%!W_]4
M0@"`4B$'@)+@`QPJ>//_EZ&C!I$B!8#2X`,<*O3S_Y<'``"0`P``D.=`,9&F
MHP:19:,ED>0#&JIC0"R1`@"`DB$`@%+@`Q>J#?/_E[?^_Q?3`D#Y;O[_%WWS
M_Y?]>[FI_0,`D?MS!:F[``"PO```L/-3`:GU6P*I]V,#J?EK!*F`@PF1`0!`
M^:$W`/D!`(#28%-"N6+S_Y<"``"0(P"`4J&3`9$#I`(Y0*`FD7GY_Y>```"T
M`0!`.3_$`'%`$0!4@_S_EV!30KFV``#05//_EP$``)!C`8!2(@"`4B&`+I%C
M\_^7P`8`M`$(0/G`(@Z1`(!0N#D40/D?!`!Q#08`5!J`@%(5`(!2,P"`4GA#
M"9$:!*!R"P``%$$(0/G@`Q>J<_/_ER`$`#7`(@Z1<P8`$;4&`!$`@%"X'P`3
M:ZT#`%0``T"Y-O/_EP,`@%*B?D"3X0,9JI[S_Y?T`P"J8`(`M`(`0/G!(@Z1
M0`Q`N2$`4?@``!H*'P`0<3?8<_C@_/]4``-`N2;S_Y>!`D#Y0P"`4@(`@-(.
M\_^7X0,`JN`#%ZI3\_^7(/S_-,`B#I$`@%"X`00`43\`%6O`"0!48%-"N;0`
M`+`6\_^7`0``D&,`@%(B`(!2(:`ND27S_Y?S`P"J@`$`M(!20KD-\_^780I`
M^0(``)!"P"Z1(0!`^>3R_Y=@"D#Y``!`^0`,0+D@$+`W8%-"N;4``+`!\_^7
M`0``D&,`@%(B`(!2(>`ND1#S_Y?S`P"JH`$`M````)"ADP&1`$`ED1/Y_Y?T
M`P"JH%)"N?0*`+3R\O^780I`^>(#%*HA`$#YRO+_EV!30KG5(@Z1MP``L.KR
M_Y<?I`(Y`@``D*&3`9%``"61`OG_EZ""$?CT`P"JH`0`M`$X@%)X\_^7`00`
M$3\$`'%I``!4'T0`<4$,`%2<@PF1H3=`^8`#0/D@``#*@`L`M?-30:GU6T*I
M]V-#J?EK1*G[<T6I_7O'J,`#7]8`!$`YX.[_-'7__Q<?!`!Q3?;_5#,`@%)T
M0PF1@`)`N7,&`!'%\O^7X0,9JG/R_Y?`(@Z1`(!0N!\`$VL,__]4IO__%Z`"
M4?C=_/^7H((1^*`'`+1A"D#Y`("`4@`$H'(A`$#Y(@Q`N4````H?`!!QX00`
M5"`(0/G6(@Z1U`)1^.$#%*K5\O^7]0,`*F$*0/D`@(!2``2@<I0"0/DA`$#Y
M(@Q`N4````H?`!!QX0$`5"((0/D```"0XP,5*N$#%*H`H"^1W?+_EYSR_Y?`
M(@Z18@I`^0$`4?A``$#Y(0!`^5?Z_Y>H__\78%-"N9/R_Y=A"D#Y`@"`TD,`
M@%(A`$#Y>O+_E^(#`*KK__\7X%)"N8KR_Y=A"D#Y0P"`4@(`@-(A`$#Y<?+_
ME]3__Q>`4D*Y@O+_EV$*0/DA`$#YV_+_EWO__Q<```"0```OD;OR_Y>&\O^7
MH0)1^`0``)#C`P`JX@,4JH!`,)$A`$#YL_+_E_U[OJG]`P"1\U,!J?0#`*I-
M^_^7\P,`J@``0#G````T808`D1^\`'%S$H&:(!1`.*#__S4&_/^70`$`-#0!
M`+2``D`YX```-`$``)#@`Q.J(:`JD>7R_Y=_`@#K@```5/-30:G]>\*HP`-?
MUN`#%*KS4T&I_7O"J$[Y_Q?]>[ZI_0,`D?,+`/FS``"P8%)"N4[R_Y<!`(`2
M1/+_EV!20KE*\O^7\PM`^>'__]`"`(#2_7O"J"&0-I'0\O\7I```L(/`")%#
M``"T@QA!^??Q_Q?]>[RI_0,`D?-3`:GW8P.IM```D+@``)`8`S>1E"(WD90"
M&,N4_D.3]5L"J?<#`"KV`P&J]0,"JA,`@-*I\?^7-`$`M`-[<_C@`Q<JX0,6
MJN(#%:I@`#_6<P8`D7\"%.LA__]4\U-!J?5;0JGW8T.I_7O$J,`#7];``U_6
M_7N_J?T#`)']>\&HP`-?U@`````!``(``````'!E<FQX<VDN8P````````!?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````````L%Q`````
M``#`7$```````,A<0```````T%Q```````#87$```````/!<0```````````
M``````"H7$```````#A90`````````````````!(6D```````(A<0```````
MD%Q```````"87$```````*!<0`````````````````!P7$```````'A<0```
M```````````````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4````
M`&5X90``````+W!R;V,O)6DO)7,``````"X`````````4$%27U1%35``````
M`````%!!4E]04D]'3D%-10`````Z`````````"\`````````)7,E<R5S``!0
M15),-4Q)0@``````````4$523$Q)0@!015),-4]05```````````4$523$E/
M``!005)?24Y)5$E!3$E:140`4$%27U-005=.140``````%!!4E]#3$5!3@``
M``````!005)?1$5"54<`````````4$%27T-!0TA%`````````%!!4E]!4D=#
M``````````!005)?05)'5E\P````````4$%27T=,3T)!3%]$14)51P``````
M````4$%27T=,3T)!3%]435!$25(`````````4$%27U1-4$1)4@```````%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.``````````!005)?0TQ%
M04X]````````,0````````!365-414T``"4P,G@`````<&%R+0`````E<R5S
M)7,E<P``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````'!A<FP`````+G!A<@``
M```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U
M+25U)7,``````````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U
M;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T
M:6]N*0H```````!!4D=6`````!@`````````<&5R;``````P`````````%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@97AE
M8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@``````````)7,````````M90```````"TM````````55-%4@``
M``!54T523D%-10``````````5$U01$E2``!414U01$E2`%1%35``````5$U0
M```````O=&UP`````$Q$7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?
M4$%42`````!$64Q$7TQ)0E)!4EE?4$%42`````````!32$Q)0E]0051(````
M````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG
M"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E
M(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ
M4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&
M25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O
M8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G
M)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E
M86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D
M=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA
M;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R
M/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A
M=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I
M"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0[
M"F5V86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.5GM005)?
M05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@/2!M87`@
M)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q
M*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@*&ME>7,@
M)45.5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PI]"GT*
M;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*
M<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL
M"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN
M*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-
M4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*
M7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*
M>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\
M)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*
M<V5E:R!?1D@L("TX+"`R.PIR96%D(%]&2"P@)&)U9BP@.#L*;&%S="!U;FQE
M<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["G-E96L@7T9(+"`M,3(L(#(["G)E
M860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@
M)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H
M<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ
M+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@*"1O=70L
M("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["FEF("@D;W5T
M*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U
M=#L*8VAM;V0@,#<U-2P@)&9I;&5N86UE.PI]"B1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U
M;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2`I('L*;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E
M;F%M921E>'0B.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*;W!E;B!M
M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&]U
M="D["G!R:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*?0IE;'-E('L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*
M;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*
M;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\[
M"G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N
M86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM
M>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U
M;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R
M(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D
M;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z
M.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE
M(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE
M+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@
M>PIM>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA
M;64M/GMC<F-]*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@
M)&]U="`D9FEL96YA;64M/GMB=69].PIC;&]S92`D;W5T.PI]"F]P96X@;7D@
M)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIR971U
M<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F
M:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*
M<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE
M(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)
M3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@
M*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE
M.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O
M<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P
M-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R
M9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*
M9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%
M(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@
M)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*
M?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET
M.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T
M*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN
M960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N
M;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H
M+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A
M(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D
M>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A
M<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H
M6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F
M:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@
M)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F
M:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A
M=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ
M1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ
M1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D
M9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@
M=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?
M1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O
M7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E
M<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM
M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L
M(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B
M("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME
M>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I
M8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI
M*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@
M*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE
M<R@I.PIM>2!`:6YC(#T@<V]R="!["FQE;F=T:"@D8BD@/#T^(&QE;F=T:"@D
M82D*?2!G<F5P('L*(2]"4T1004XO"GT@9W)E<"!["B@D8G5N9&QE(&YE("=S
M:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A
M;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#
M.PIM>2`E9FEL97,["B]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[
M)#%]*RL@9F]R(&ME>7,@)3HZ.PHD9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E
M24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*
M;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@
M*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]
M("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:
M+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I
M9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R
M968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R
M:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE
M(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K
M:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q
M*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N
M=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L
M("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E
M*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I
M"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M
M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA
M<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET
M=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT
M*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#
M,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]
M"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H
M95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@
M)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(
M02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$
M:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V
M97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2![
M"B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92![
M"FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D
M92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD
M8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64[
M"GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L
M96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD
M9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U
M;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E
M<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*
M<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B
M)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B
M.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD
M<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D[
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E
M="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM
M96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D
M;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@
M)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO
M*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D
M97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]
M+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]
M/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP
M<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A
M="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG
M("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE
M>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D
M97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S
M($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M
M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\
M+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T
M95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N
M86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE
M.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D
M<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E
M7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR
M97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI
M;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E
M<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@
M>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M
M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.
M5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0
M("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E
M9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S
M97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H
M)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G
M:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*
M96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*
M?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM5
M4T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY
M("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K
M*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H
M(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N
M86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E
M96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H
M)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A
M9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@
M)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(
M02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$
M:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V
M97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2![
M"B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE
M;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I
M*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D
M9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@
M+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S
M92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*
M)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1E>'0L
M("1C<F,I(#T@0%\["FUY("@D9F@L("1F:6QE;F%M92D["B1F:6QE;F%M92`]
M("(D<&%R7W1E;7`O)&-R8R1E>'0B.PII9B`H)$5.5GM005)?0TQ%04Y]*2![
M"G5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PIP=7-H($!T;7!F
M:6QE+"`D9FEL96YA;64["GT*96QS92!["G)E='5R;B`H=6YD968L("1F:6QE
M;F%M92D@:68@*"UR("1F:6QE;F%M92D["GT*;W!E;B`D9F@L("<^)RP@)&9I
M;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIR971U<FXH)&9H+"`D
M9FEL96YA;64I.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D[
M"GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G
M/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF
M:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I
M9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?
M5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P
M<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE
M('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@
M*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R
M;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P
M=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ
M("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@
M.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<
M+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN
M:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@
M>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#([
M"GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!2
M3T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD
M7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD
M14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X
M:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@
M/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.
M5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I
M9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU
M92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D[
M"B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!
M3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF
M("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I
M;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<[
M"G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG
M>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S
M:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C
M:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ
M9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N
M<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U
M8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*
M9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@
M/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z
M.E]?15)23U(["C$["E]?14Y$7U\*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#@F0```````""9```````````````````$`
M`````````0`````````!``````````4"`````````0````````!4`@``````
M``$`````````IP,````````,`````````$@>0```````#0````````#D5T``
M`````!D`````````P)U!```````;``````````@`````````&@````````#(
MG4$``````!P`````````"`````````#U_O]O`````&`"0```````!0``````
M``"@$$````````8`````````(`9````````*`````````$(%````````"P``
M```````8`````````!4````````````````````#`````````.B?00``````
M`@````````!X!@```````!0`````````!P`````````7`````````-`70```
M````!P`````````H%T````````@`````````J``````````)`````````!@`
M````````_O__;P````#(%D```````/___V\``````P````````#P__]O````
M`.(50```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````V)U!````````````````````````````````````
M`````````````&`>0```````8!Y```````!@'D```````&`>0```````8!Y`
M``````!@'D```````&`>0```````8!Y```````!@'D```````&`>0```````
M8!Y```````!@'D```````&`>0```````8!Y```````!@'D```````&`>0```
M````8!Y```````!@'D```````&`>0```````8!Y```````!@'D```````&`>
M0```````8!Y```````!@'D```````&`>0```````8!Y```````!@'D``````
M`&`>0```````8!Y```````!@'D```````&`>0```````8!Y```````!@'D``
M`````&`>0```````8!Y```````!@'D```````&`>0```````8!Y```````!@
M'D```````&`>0```````8!Y```````!@'D```````&`>0```````8!Y`````
M``!@'D```````&`>0```````8!Y```````!@'D```````&`>0```````8!Y`
M``````!@'D```````&`>0```````8!Y```````!@'D```````&`>0```````
M8!Y```````!@'D```````&`>0```````8!Y```````!@'D```````&`>0```
M````8!Y```````!@'D```````&`>0```````8!Y```````!@'D```````&`>
M0```````8!Y```````!@'D````````````````````````````#_____````
M``!=0```````1T-#.B`H56)U;G1U+TQI;F%R;R`T+CDN,BTQ,'5B=6YT=3<I
M(#0N.2XR`$=#0SH@*%5B=6YT=2],:6YA<F\@-"XX+C0M,75B=6YT=30I(#0N
M."XT```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N
M=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R
M<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET
M`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF
M:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N
M8G-S`"YC;VUM96YT````````````````````````````````````````````
M````````````````````````````````````````````"P````$````"````
M```````"0`````````(````````;`````````````````````0``````````
M`````````!,````'`````@`````````<`D```````!P"````````(```````
M``````````````0````````````````````A````!P````(`````````/`)`
M```````\`@```````"0````````````````````$````````````````````
M-````/;__V\"`````````&`"0```````8`(```````#``P````````4`````
M````"````````````````````#X````+`````@`````````@!D```````"`&
M````````@`H````````&`````0````@`````````&`````````!&`````P``
M``(`````````H!!```````"@$````````$(%```````````````````!````
M````````````````3@```/___V\"`````````.(50```````XA4```````#@
M``````````4``````````@`````````"`````````%L```#^__]O`@``````
M``#(%D```````,@6````````8``````````&`````P````@`````````````
M``````!J````!`````(`````````*!=````````H%P```````*@`````````
M!0`````````(`````````!@`````````=`````0```!"`````````-`70```
M````T!<```````!X!@````````4````,````"``````````8`````````'X`
M```!````!@````````!('D```````$@>````````%```````````````````
M``0```````````````````!Y`````0````8`````````8!Y```````!@'@``
M`````'`$```````````````````0`````````!``````````A`````$````&
M`````````-`B0```````T"(````````4-0``````````````````"```````
M`````````````(H````!````!@````````#D5T```````.17````````$```
M``````````````````0```````````````````"0`````0````(`````````
M^%=```````#X5P```````!!!```````````````````(````````````````
M````F`````$````"``````````B90```````")D````````$````````````
M````````!````````````````````*(````.`````P````````#`G4$`````
M`,"=````````"`````````````````````@```````````````````"N````
M#P````,`````````R)U!``````#(G0````````@````````````````````(
M````````````````````N@````$````#`````````-"=00``````T)T`````
M```(````````````````````"````````````````````+\````&`````P``
M``````#8G4$``````-B=``````````(````````&``````````@`````````
M$`````````#(`````0````,`````````V)]!``````#8GP```````!``````
M```````````````(``````````@`````````S0````$````#`````````.B?
M00``````Z)\```````!``@``````````````````"``````````(````````
M`-8````!`````P`````````HHD$``````"BB````````(```````````````
M``````@```````````````````#<````"`````,`````````2*)!``````!(
MH@```````&@0```````````````````(````````````````````X0````$`
M```P````````````````````2*(```````!5`````````````````````0``
M```````!``````````$````#`````````````````````````)VB````````
@Z@````````````````````$`````````````````````
